@@ -11,7 +11,7 @@ for prefix in $PREFIXES; do
 	#echo $prefix >&2
 	for pkgid in $LIST; do
 		#echo $pkgid >&2
-		for pkg in `ls -1 ${prefix}/${pkgid}*.jar ${prefix}/apache-${pkgid}*.jar 2>/dev/null`; do
+		for pkg in `ls -1 ${prefix}/${pkgid}*.jar ${prefix}/apache-${pkgid}*.jar ${prefix}/jakarta-${pkgid}*.jar 2>/dev/null`; do
 			if ! test -h ${pkg}; then
 				CP="$CP:${pkg}"
 			fi
